// $Id: J4CDCDriftRegion.cc,v 1.1.1.1 2001/08/31 07:38:35 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4CDCDriftRegion
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4CDCDriftRegion.hh"
#include "J4CDCDriftRegionSD.hh"

//************************************************************************
//--------------------------------
// constants (detector parameters)
//--------------------------------



G4String J4CDCDriftRegion::fName("DriftRegion");


//************************************************************************
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4CDCDriftRegion::J4CDCDriftRegion(J4VDetectorComponent *parent,
				   G4int nclones,
  		  	           G4int nbrothers, 
  		  	           G4int me ) : 
  		J4VCDCDetectorComponent( fName, parent, nclones,
  					 nbrothers, me  ), fSenseWire(0)
{   
}


//=====================================================================
//* destructor --------------------------------------------------------

J4CDCDriftRegion::~J4CDCDriftRegion()
{	
  if(fSenseWire) delete fSenseWire;
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4CDCDriftRegion::Assemble()
{   
  if(!GetLV())
  {	  
    // define parameters
    
    G4double len  = 
        ((G4Tubs *)GetMother()->GetLV()->GetSolid())->GetZHalfLength() ;        
    G4double motherRmin = 
        ((G4Tubs *)GetMother()->GetLV()->GetSolid())->GetInnerRadius() ;       
    G4double motherRmax = 
        ((G4Tubs *)GetMother()->GetLV()->GetSolid())->GetOuterRadius() ;        
    G4double phi = 
        ((G4Tubs *)GetMother()->GetLV()->GetSolid())->GetDeltaPhiAngle() ;
        
    G4int    nbrothers  = GetNBrothers();
    G4int    myid       = GetMyID();
    G4double thick      = (motherRmax - motherRmin)/(nbrothers + 2);
    G4double rmin       = motherRmin + thick * (myid + 1);
    G4double rmax       = motherRmin + thick * (myid + 2);
       
    // MakeSolid ----------//
    OrderNewTubs (rmin, rmax, len, phi );

    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()->Order(_CDCDRIFTREGIONMATERIAL_));
    
    // SetVisAttribute ----//
    PaintLV(_CDCDriftRegionVisAtt_, G4Color(0.,1.,1.));   
    
         
    // Install daughter PV //
    // Install Sense Wire  //
  
    fSenseWire = new J4CDCSenseWire(this);
    fSenseWire->InstallIn(this);
    
    SetDaughter(fSenseWire); 
    
  }
    
}

//=====================================================================
//* Cabling   ---------------------------------------------------------

void J4CDCDriftRegion::Cabling()
{
  if (!GetLV()) Assemble(); 

//  G4cerr << "J4CDCDriftRegion:Cabling is called " << G4endl;

  J4CDCDriftRegionSD* sd = new J4CDCDriftRegionSD(this);
  SetSD(sd);
	
}
//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4CDCDriftRegion::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
    
  SetPVPlacement(0,0);
  
  if (!GetSD()) Cabling();
  
}

//=====================================================================
//* SwitchOn  --------------------------------------------------------
void J4CDCDriftRegion::SwitchOn(G4String opt)
{
  J4VDetectorComponent::SwitchOn(opt);
}

//=====================================================================
//* SwitchOff  --------------------------------------------------------
void J4CDCDriftRegion::SwitchOff(G4String opt)
{
  J4VDetectorComponent::SwitchOff(opt);
}

//=====================================================================
//* Draw  --------------------------------------------------------

void J4CDCDriftRegion::Draw()
{
  // set visualization attributes
  
}
	
//=====================================================================
//* Print  --------------------------------------------------------

void J4CDCDriftRegion::Print() const
{
}

	
	
