// $Id: Jupiter.cc,v 1.1.1.1 2001/08/31 07:38:34 hoshina Exp $
// ====================================================================
//    Jupiter.cc
//   
//    Exapmle program provided by JLC-CDC group.
//
//    NOTE:
//    Please contact me(hoshina@jlcux1.kek.jp) if any problems 
//    or questions. DO NOT bother Geant4 developpers and Geant4 Users
//    Group Japan.
//
//                                K.Hoshina , 2001
// ====================================================================
#include <strstream.h>
#include "G4RunManager.hh"
#include "G4UIterminal.hh"
#include "G4UItcsh.hh"

#include "J4DetectorConstruction.hh"
#include "J4PhysicsList.hh"
#include "J4PrimaryGeneratorAction.hh"
#include "J4RunAction.hh"
#include "J4EventAction.hh"
#include "J4TrackingAction.hh"

#ifdef G4VIS_USE
#include "J4VisManager.hh"
#endif

//#include "CLHEP/Random/Random.h"

#include "J4Beampipe.hh"
#include "J4VTX.hh"
#include "J4IT.hh"
#include "J4CDC.hh"
#include "J4CAL.hh"




int main(int argc, char** argv) 
{
	
  //-------------------------
  // Set random engine....
  //-------------------------
  // if you want to change a random engine, for example, ...
  
#if 0
  HepJamesRandom randomEngine;
  //RanecuEngine randomEngine;
  HepRandom::setTheEngine(&randomEngine);
#endif

  //-------------------------
  // Set run manager 
  //-------------------------

  G4RunManager* runManager = new G4RunManager;  G4cout << endl;

  //---------------------------------------------
  // set mandatory user initialization classes...
  
  //*--------------------------------------------
  //* Install detector components...
  //*--------------------------------------------
  
  J4DetectorConstruction* dtcptr = new J4DetectorConstruction;
  
  //* beam line 
  
  J4Beampipe  *beampipeptr = new J4Beampipe();
  beampipeptr->SetMother(dtcptr->GetExpHall());
  dtcptr->AddComponent(beampipeptr);
  
  //* vtx 
  
  J4VTX *vtxptr = new J4VTX();
  vtxptr->SetMother(dtcptr->GetExpHall());
  dtcptr->AddComponent(vtxptr);
  
  //* intermediate tracker 
  
  J4IT *itptr = new J4IT();
  itptr->SetMother(dtcptr->GetExpHall());
  dtcptr->AddComponent(itptr);
  
  //* cdc 
    
  J4CDC *cdcptr = new J4CDC();
  cdcptr->SetMother(dtcptr->GetExpHall());
  dtcptr->AddComponent(cdcptr);
  
  //* calorimeter 
    
  J4CAL *calptr = new J4CAL();
  calptr->SetMother(dtcptr->GetExpHall());
  dtcptr->AddComponent(calptr);
  
  //*--------------------------------------------
  //* Installation of detectors end
  //*--------------------------------------------
       
  runManager-> SetUserInitialization(dtcptr);
  
  // particles and physics processes

  runManager-> SetUserInitialization(new J4PhysicsList);

  //---------------------------------------------
  // set mandatory user action class...
  
  //* primary generator

  J4PrimaryGeneratorAction* primarygenerator = new J4PrimaryGeneratorAction;
  
#if 1
  primarygenerator->UseHEPEvtGenerator();	//Pythia event
#else
  primarygenerator->UseHEPEvtGenerator(FALSE);	//Muon random gauss
#endif

  runManager-> SetUserAction(primarygenerator);

  //* user action classes... (optional)

  runManager-> SetUserAction(new J4RunAction);
  runManager-> SetUserAction(new J4EventAction);
  runManager-> SetUserAction(new J4TrackingAction);

#ifdef G4VIS_USE
  // initialize visualization package
  G4VisManager* visManager= new J4VisManager;
  visManager-> Initialize();
  G4cout << endl;
#endif

  //-----------------------
  // user session start
  //-----------------------

  runManager-> Initialize();
  
  
  //*--------------------------------------------
  //* SwitchOn/Off your detector...
  //*--------------------------------------------
  //* If you wants call SwitchOn/Off recursively,
  //* call virtual function with resolver, as
  //* "J4VDetectorComponent::SwitchOn()".
  //* SwitchOn/(Off() requires option flag
  //* "recursive" or other strings, however,
  //* default value is set as "recursive".
 
 
  //* vtx 
  
  vtxptr->J4VDetectorComponent::SwitchOn();
   
  //* cdc 
  
  // SwitchOn all SDs.
  cdcptr->J4VDetectorComponent::SwitchOn(); 
 
  // Then, SwitchOff only SenseWires.
  for (G4int i=0; i<10; i++) {
     for (G4int j=0; j<5; j++) {
        strstream str;
        str << "ExpName:CDC:Layer0" << i << ":Cell:DriftRegion"
            << j << ":SenseWire" ;           
        G4String name;
        str >> name;
        J4VDetectorComponent::GetDCPtrByName(name)->SwitchOff(); 
     }
  }
        
  //*--------------------------------------------
  //* Detector Switch end
  //*--------------------------------------------
  
    
  if(argc==1) { 		// interactive session, if no arguments given

#ifdef USE_CSH_TERMINAL    
    // csh-like
    G4UIterminal* session= new G4UIterminal();
    session-> SetPrompt("G4test(%s)[%/]:");
#else
    // tcsh-like
    G4UItcsh* tcsh= new 
      G4UItcsh("[36mexU01[33m(%s)[32m[%/][36m[%h][37m:");
    G4UIterminal* session= new G4UIterminal(tcsh);
    tcsh-> SetLsColor(GREEN, CYAN);
#endif

    session-> SessionStart();
    delete session;

  } else { 			// batch mode

    G4UImanager* UImanager= G4UImanager::GetUIpointer();
    G4String command = "/control/execute ";
    G4String fileName = argv[1];
    UImanager-> ApplyCommand(command+fileName);

  }

  //-----------------------
  // terminating...
  //-----------------------

#ifdef G4VIS_USE
  delete visManager;
#endif

  delete runManager;  G4cout << endl;
  return 0;

}

