// $Id: J4VDetectorComponent.hh,v 1.1.1.1 2001/08/31 07:38:34 hoshina Exp $
#ifndef __J4VDETECTORCOMPONENT__
#define __J4VDETECTORCOMPONENT__
//*************************************************************************
//* --------------------
//* J4VDetectorComponent
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "g4rw/tpordvec.h"

#include "G4VSolid.hh"
#include "G4VPhysicalVolume.hh"
#include "G4LogicalVolume.hh"
#include "J4VSensitiveDetector.hh" 
#include "G4VisAttributes.hh"
#include "G4SDManager.hh"
#include "G4PVPlacement.hh"
#include "G4PVReplica.hh"
#include "G4UserLimits.hh"

#include "J4Object.hh"
#include "J4VMaterialStore.hh"
#include "J4Parameter.hh"

//for OrderSolid
#include "G4Tubs.hh"
#include "J4TypeDef.hh"

class J4VDetectorComponent;

//=====================================================================
//---------------------
// class definition
//---------------------

class J4VDetectorComponent : public J4Object
{

public:

 //default constructor...
   
  J4VDetectorComponent( G4String& groupname,
  			G4String& name, 
  			J4VDetectorComponent *parent = 0,
  			G4int     nclones   = 1,
  			G4int     nbrothers = 1, 
  			G4int     me        = 0 );
  			
  J4VDetectorComponent(J4VDetectorComponent& right);
    		       
 //destructor...
  
  virtual ~J4VDetectorComponent();
  
  virtual const J4VDetectorComponent& operator=(const J4VDetectorComponent& right);    

  virtual void	InstallIn(J4VDetectorComponent* mother) = 0;
  virtual void	Draw()        = 0;
  virtual void	Print() const = 0;
  
  virtual void  OutputAll(G4HCofThisEvent* HCTE);
  virtual void	SwitchOn (G4String opt = "recursive") ; 
  virtual void	SwitchOff(G4String opt = "recursive") ;
  
  virtual G4bool IsOn() 	{ return fIsOn; }
  virtual G4bool IsInstalled()  { return fInstalled; }
   
 //Get Method...
  
  virtual G4VSolid*	          GetSolid()    { return fSolid;    }
  virtual G4LogicalVolume*	  GetLV()       { return fLV;       }
  virtual J4VSensitiveDetector*   GetSD()       { return fSD;       }
  virtual G4VPhysicalVolume*	  GetPV()       { return fPV;       }
  virtual J4VDetectorComponent*	  GetMother()   { return fMother;   }
  virtual G4int			  GetNBrothers(){ return fNBrothers;}
  virtual G4int			  GetMyID    () { return fMyID;     } 
  virtual G4int			  GetNClones () { return fNClones;  } 
  virtual G4String& 		  GetSubGroup() { return fSubGroup; }   
  virtual G4String& 		  GetName()     { return fName;     }
  
 //Set Method...
  
  virtual void SetDaughter(J4VDetectorComponent* daughter);
  virtual void SetMother  (J4VDetectorComponent* mother  );
  virtual void SetSolid   (G4VSolid* solid)          { fSolid  = solid;}
  virtual void SetLV      (G4LogicalVolume* lv)      { fLV     = lv;   }
  virtual void SetPV      (G4VPhysicalVolume*    pv) { fPV     = pv;   }
  virtual void SetSD      (J4VSensitiveDetector* sd);
  virtual void SetIsOn    (G4bool flag)              { fIsOn   = flag; }    
  virtual void SetName    (G4String& name,
		           G4int     nbrothers = 1,
		           G4int     me        = 0,
		           J4VDetectorComponent *parent = 0);		    	 
 //User Tools ...
 
  virtual void MakeLVWith (G4Material* material, G4UserLimits* ulp = 0);
  virtual void PaintLV    (G4bool visiblility, const G4Color& color); 
  
  	    	 
 //Order G4Solid...

  virtual void OrderNewTubs ( G4double rmin,
  			      G4double rmax,
  			      G4double len,
  			      G4double totalphi = 360.*deg,
  			      G4double endcaphalfthickness = 0.,
  			      G4double endcaprmin = DBL_MAX,
  			      G4double sphi = DBL_MAX);	// If sphi=DBL_MAX,
  			      				// sphi is replaced
  			      				// to -(dphi/2.).
  			      				
  static J4VDetectorComponent *GetDCPtrByName(const G4String& name);			      
  
  		  			      				  			      
protected:
  					     
 //PVPlacement method
  virtual void SetPVPlacement (G4RotationMatrix *pRot = 0,
                               const G4ThreeVector &tlate = 0);
  virtual void SetPVReplica   (const EAxis pAxis, G4double step,
  			       const G4double offset=0);
 
private:
  			       
  virtual void 			Assemble() = 0;
  virtual void			Cabling () = 0;
  virtual J4VMaterialStore*	OpenMaterialStore();
  virtual G4String		GetNewName(G4String& middlename, 
  					   G4int     me    = 1, 
  					   G4int     width = 0, 
  					   G4String* parentname = 0);  
  					   
private: 

  G4SDManager*		 fSDManager;     
  G4String		 fSubGroup;
  G4String		 fName;
  J4VDetectorComponent*  fMother;
  J4DtcComponentArray    fDaughters;
  G4bool	         fIsOn;
  G4bool	         fInstalled;
  G4VSolid*              fSolid; 
  G4LogicalVolume*       fLV;
  G4VPhysicalVolume*     fPV;
  J4VSensitiveDetector*  fSD;  
  G4int 		 fNClones;
  G4int			 fNBrothers;
  G4int			 fMyID;
  G4bool		 fCanDeleteUserLimits;
  G4bool		 fIsDaughterOn;
  
  static J4DtcComponentArray fgFamilyMembers;
      
};


//=====================================================================
//---------------------
// inline function
//---------------------

inline J4VDetectorComponent::J4VDetectorComponent(J4VDetectorComponent& right)
{

  fSDManager = right.fSDManager  ;
  fSubGroup  = right.fSubGroup   ;
  fName      = right.fName	 ;
  fMother    = right.fMother     ;
  fDaughters = right.fDaughters  ;
  fInstalled = right.fInstalled  ;
  fSolid     = right.fSolid      ;
  fLV        = right.fLV	 ;
  fPV	     = right.fPV	 ;
  fSD	     = right.fSD	 ;
  fNClones   = right.fNClones    ;
  fNBrothers = right.fNBrothers  ;
  fMyID      = right.fMyID       ;
          
}

inline const J4VDetectorComponent& 
J4VDetectorComponent::operator= (const J4VDetectorComponent& right)
{

  fSDManager = right.fSDManager  ;
  fSubGroup  = right.fSubGroup   ;
  fName      = right.fName	 ;
  fMother    = right.fMother     ;
  fDaughters = right.fDaughters  ;
  fInstalled = right.fInstalled  ;
  fSolid     = right.fSolid      ;
  fLV        = right.fLV	 ;
  fPV	     = right.fPV	 ;
  fSD	     = right.fSD	 ;
  fNClones   = right.fNClones    ;
  fNBrothers = right.fNBrothers  ;
  fMyID      = right.fMyID       ;
  
  return *this;
            
}


#endif


