// $Id: J4DetectorConstruction.cc,v 1.1.1.1 2001/08/31 07:38:35 hoshina Exp $
//*************************************************************************
//* --------------------------
//* J4DetectorConstruction.cc
//* --------------------------
//* (Description)
//* 	
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************


#include "J4DetectorConstruction.hh"
#include "J4ExpHall.hh"
#include "J4MagneticField.hh"

#include "G4FieldManager.hh"
#include "G4TransportationManager.hh"
#include "G4ChordFinder.hh"


J4ExpHall* J4DetectorConstruction::fExpHall = 0; 

//************************************************************************
//---------------------
// Class Description
//---------------------
 
//=====================================================================
//* constructor -------------------------------------------------------

J4DetectorConstruction::J4DetectorConstruction() : fComponents(64)
{  
   fExpHall  = new J4ExpHall(0, 1, 1, 0);
}

//=====================================================================
//* destructor --------------------------------------------------------

J4DetectorConstruction::~J4DetectorConstruction()
{
  if (fExpHall) delete fExpHall;
  if (!fComponents.isEmpty()) fComponents.clearAndDestroy();
}

//=====================================================================
//* Construct   -------------------------------------------------------

G4VPhysicalVolume* J4DetectorConstruction::Construct()
{
        
  //------------------------------------------------
  // Install all components in Experimental Hall....
  //------------------------------------------------
  
    G4int ncomponents = fComponents.entries();
    
    for (G4int i=0; i<ncomponents; i++) {
    		
    	J4VDetectorComponent* detector 
    		= (J4VDetectorComponent *)fComponents.operator[](i);     
    	detector->InstallIn(fExpHall);
    	fExpHall->SetDaughter(detector);
    	
    }  
    
  // ---------------------------
  // magnetic field
  // ---------------------------
  
    G4FieldManager* fieldManager= 
      G4TransportationManager::GetTransportationManager()-> GetFieldManager();

    J4MagneticField* magField= new J4MagneticField;
    fieldManager-> SetDetectorField(magField);
    fieldManager-> CreateChordFinder(magField);
    fieldManager-> GetChordFinder()-> SetDeltaChord(3.*mm);  // if you need
  
  // ==============================================================
  // return PV of the world volume
  return fExpHall->GetPV();
}

