// $Id: J4VTX.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4VTX
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4VTX.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------

G4String J4VTX::fName("VTX");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4VTX::J4VTX(J4VDetectorComponent *parent ,
G4int nclones, G4int nbrothes, G4int me):
  J4VVTXDetectorComponent( fName, parent, 1,1,0)
{   
}

//=====================================================================
//* destructor --------------------------------------------------------

J4VTX::~J4VTX()
{
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4VTX::Assemble() 
{   
  if(!GetLV()){

    //--- Assemble Master volume for VTX ----
    G4double rmin = VTXMASTER_INNER_R;
    G4double rmax = VTXMASTER_OUTER_R;
    G4double len  = VTXMASTER_Z/2.;
    G4double dphi = VTXMASTER_PHI;
 	
    // MakeSolid ----------//
    OrderNewTubs (rmin, rmax, len, dphi);
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()->Order(_MASTERMATERIAL_));
    // SetVisAttribute ----//
    PaintLV(_VTXVISATT_, G4Color(0, 0, 0));
  	

    // Install daughter PV //
    // Install Layer       //
    fLayer = new J4VTXLayer* [NLAYER];
    for (G4int i = 0; i < NLAYER ; i++) {
      fLayer[i] = 
	new J4VTXLayer(this,NLAYER , i );
      fLayer[i]->InstallIn(this);  
      SetDaughter(fLayer[i]);
      fLayer[i]->Print();
    }  
    Print();
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4VTX::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4VTX::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object...
  
  SetPVPlacement();
  
}


//* Draw  --------------------------------------------------------
void J4VTX::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4VTX::Print() const
{
    G4double rmin = VTXMASTER_INNER_R;
    G4double rmax = VTXMASTER_OUTER_R;
    G4double len  = VTXMASTER_Z;
    G4double dphi = VTXMASTER_PHI;
    cout << "VTX Master Volume " <<endl;
    cout << "Rmin " << rmin/mm << " Rmax " << rmax/mm<<" Z"<< len/mm<<endl;
}

	
	

