// $Id: J4VTXEpitaxial.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4VTXEpitaxial
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4VTXEpitaxial.hh"
#include "G4Box.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------


G4String J4VTXEpitaxial::fName("Epitaxial");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4VTXEpitaxial::J4VTXEpitaxial(J4VDetectorComponent* parent):
  	   J4VVTXDetectorComponent(fName, parent, 1,1, 0)
{   
  // Define Epitaxial parameters ----------------//    
  fDxyzEpitaxial = new G4ThreeVector(DXYZ_EPITAXIAL);
  fxyzEpitaxial  = new G4ThreeVector(XYZ_EPITAXIAL);
}

//=====================================================================
//* destructor --------------------------------------------------------

J4VTXEpitaxial::~J4VTXEpitaxial()
{
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4VTXEpitaxial::Assemble() 
{   
  if(!GetLV())
  {	  
    // define geometry
      
    // MakeSolid ----------//
    SetSolid(new G4Box(fName,fDxyzEpitaxial->x()/2.,
		                fDxyzEpitaxial->y()/2.,
		                fDxyzEpitaxial->z()/2.));
    
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()-> Order(_EPITAXIALMATERIAL_));
    
    // SetVisAttribute ----//
    PaintLV( _EPITAXIALVISATT_ , G4Color(0.0,1.,0.0));    

    SetMaxAllowedStep(0.001*mm);
        
    // Install daughter PV //
    // Install PixelArea      //
    fPixelArea = new J4VTXPixelArea(this);
    fPixelArea->InstallIn(this);  
    SetDaughter(fPixelArea);
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4VTXEpitaxial::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4VTXEpitaxial::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object ------//
  G4RotationMatrix* rotM = new G4RotationMatrix;
  SetPVPlacement(rotM,*fxyzEpitaxial);
}


//* Draw  --------------------------------------------------------
void J4VTXEpitaxial::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4VTXEpitaxial::Print() const
{
  cout << "-J4VTXEpitaxial(mm)  "<< endl;
  cout << "dx " << fDxyzEpitaxial->x()/mm 
       << " dy "<< fDxyzEpitaxial->y()/mm 
       << " dz "<< fDxyzEpitaxial->z()/mm 
       << endl;
  cout << "x " << fxyzEpitaxial->x()/mm 
       << " y "<< fxyzEpitaxial->y()/mm 
       << " z "<< fxyzEpitaxial->z()/mm 
       << endl;
  cout << "----------------" << endl;
  
}




