// $id: J4VTXLadder.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4VTXLadder
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4VTXLadder.hh"
#include "G4Box.hh"
#include "J4VTXParameter.hh"
#include "J4VTXMaterialStore.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------


G4String J4VTXLadder::fName("Ladder");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4VTXLadder::J4VTXLadder(J4VDetectorComponent* parent, G4int numOfLadders):
  	   J4VVTXDetectorComponent(fName, parent, numOfLadders,1, 0)
{   
  // Define Ladder parameters ----------------//    
  G4int layer = parent->GetMyID();
  fDxyzLadder = DXYZ_LADDER[layer];
}

//=====================================================================
//* destructor --------------------------------------------------------

J4VTXLadder::~J4VTXLadder()
{
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4VTXLadder::Assemble() 
{   
  if(!GetLV())
  {	  

    // define geometry
    // MakeSolid ----------//
    SetSolid( new G4Box(fName, fDxyzLadder->x()/2.,
			          fDxyzLadder->y()/2.,
			          fDxyzLadder->z()/2. ));

    MakeLVWith(OpenMaterialStore()-> Order(_LADDERMATERIAL_));

    // SetVisAttribute ----//
    PaintLV( _VTXLADDERVISATT_ , G4Color(0.,1.,1.));    
        
    // Install daughter PV //
    // Install Sensor      //
    G4int layer = GetMother()->GetMyID();
    G4int numOfSensors = NSENSOR[layer];
    fSensor  = new J4VTXSensor(this,numOfSensors);
    fSensor->InstallIn(this);  
    SetDaughter(fSensor);
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4VTXLadder::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4VTXLadder::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 

  G4int layer = mother->GetMyID();
  G4int numOfLadders = NLADDER[layer];
  for ( int copyNo = 0 ; copyNo < numOfLadders; copyNo++ ){
    fxyzLadder  = new G4ThreeVector(XYZ_LADDER[layer][copyNo]);
    fAngle =  ANGLE_LADDER[layer][copyNo];
    // Placement function into mother object ------//
    G4RotationMatrix* rotM = new G4RotationMatrix;
    rotM->rotateZ(fAngle);
    SetPVPlacement(rotM,*fxyzLadder,copyNo);
  }
}


//* Draw  --------------------------------------------------------
void J4VTXLadder::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4VTXLadder::Print() const
{
  cout << "-J4VTXLadder(mm)-  " <<endl;
  cout << "dx " << fDxyzLadder->x()/mm 
       << " dy "<< fDxyzLadder->y()/mm 
       << " dz "<< fDxyzLadder->z()/mm 
       << endl;
  cout << "x " << fxyzLadder->x()/mm 
       << " y "<< fxyzLadder->y()/mm 
       << " z "<< fxyzLadder->z()/mm 
       << endl;
  cout << "----------------" << endl;
}

	
	
