// $Id: J4VTXLayer.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4VTXLayer
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4VTXLayer.hh"
#include "G4Tubs.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------


G4String J4VTXLayer::fName("Layer");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4VTXLayer::J4VTXLayer(J4VDetectorComponent* parent,
  		  	              G4int  nbrothers, 
  		  	              G4int  me ) :
  	   J4VVTXDetectorComponent(fName, parent, 1,nbrothers, me)
{   

  // Define Layer parameters ----------------//    

    fRmin = RINNER_LAYER[me];
    fRmax = ROUTER_LAYER[me];
    fLen  = VTXMASTER_Z/2.;
    fTotalPhi = ((G4Tubs *)parent->GetLV()->GetSolid())->GetDeltaPhiAngle();
    cout << "VTXLayer "<< me << " " << fRmin/mm <<" " <<fRmax/mm<<endl;
    
}

//=====================================================================
//* destructor --------------------------------------------------------

J4VTXLayer::~J4VTXLayer()
{

}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4VTXLayer::Assemble() 
{   
  if(!GetLV())
  {	  
    // define geometry
    // MakeSolid ----------//
    OrderNewTubs (fRmin, fRmax, fLen, fTotalPhi );
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()-> Order(_LAYERMATERIAL_));
    // SetVisAttribute ----//
    PaintLV( _VTXLAYERVISATT_ , G4Color(1,0,0));    
        
    // Install daughter PV //
    // Install Ladder      //
    G4int layer = GetMyID();
    G4int numOfLadders = NLADDER[layer];
    fLadder  = new J4VTXLadder(this,numOfLadders);
    fLadder->InstallIn(this);  
    SetDaughter(fLadder);
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4VTXLayer::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4VTXLayer::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object ------//
  
  SetPVPlacement();
  
}


//* Draw  --------------------------------------------------------
void J4VTXLayer::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4VTXLayer::Print() const
{
  cout << "-J4VTXLayer(mm)-  " <<endl;
  cout << "Rmin " << fRmin/mm 
       << " Rmax "<< fRmax/mm 
       <<" Z "<< fLen/mm 
       << endl;
  cout << "----------------" << endl;
}

	
	
