// $Id: J4VTXPixelArea.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4VTXPixelArea
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4VTXPixelArea.hh"
#include "G4Box.hh"
#include "J4VTXROGeometry.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------


G4String J4VTXPixelArea::fName("PixelArea");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4VTXPixelArea::J4VTXPixelArea(J4VDetectorComponent* parent)
  	   :J4VVTXDetectorComponent(fName, parent, 1,1, 0)
{   
  // Define PixelArea parameters ----------------//    
  fDxyzPixelArea = new G4ThreeVector(DXYZ_PIXELAREA);
  fxyzPixelArea  = new G4ThreeVector(XYZ_PIXELAREA);
}

//=====================================================================
//* destructor --------------------------------------------------------

J4VTXPixelArea::~J4VTXPixelArea()
{
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4VTXPixelArea::Assemble() 
{   
  if(!GetLV())
  {	  
    // define geometry
      
    // MakeSolid ----------//
    SetSolid(new G4Box(fName,fDxyzPixelArea->x()/2.,
		                fDxyzPixelArea->y()/2.,
		                fDxyzPixelArea->z()/2.));
    
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()-> Order(_PIXELAREAMATERIAL_));
    
    // SetVisAttribute ----//
    PaintLV( _PIXELAREAVISATT_ , G4Color(0.0,0.0,0.0));    

    SetMaxAllowedStep(0.001*mm);
        
    // Install daughter PV //
    // Install PixelArea      //
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4VTXPixelArea::Cabling()
{
  if(!GetLV()) Assemble();

  J4VTXPixelAreaSD* sd = new J4VTXPixelAreaSD(this);
  J4VTXROGeometry* ro = new J4VTXROGeometry("VTXRO");
  ro->BuildROGeometry();
  sd->SetROgeometry(ro);
  SetSD(sd);

}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4VTXPixelArea::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object ------//
  G4RotationMatrix* rotM = new G4RotationMatrix;
  SetPVPlacement(rotM,*fxyzPixelArea);

  if (!GetSD()) Cabling(); 
  
}


//* SwitchOn  --------------------------------------------------------
void J4VTXPixelArea::SwitchOn(G4String opt)
{
  J4VDetectorComponent::SwitchOn(opt);
}

//* SwitchOff  --------------------------------------------------------
void J4VTXPixelArea::SwitchOff(G4String opt)
{
  J4VDetectorComponent::SwitchOff(opt);
}

//* Draw  --------------------------------------------------------
void J4VTXPixelArea::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4VTXPixelArea::Print() const
{
  cout << "-J4VTXPixelArea(mm)-  " <<endl;
  cout << "dx " << fDxyzPixelArea->x()/mm 
       << " dy "<< fDxyzPixelArea->y()/mm 
       << " dz "<< fDxyzPixelArea->z()/mm 
       << endl;
  cout << "x " << fxyzPixelArea->x()/mm 
       << " y "<< fxyzPixelArea->y()/mm 
       << " z "<< fxyzPixelArea->z()/mm 
       << endl;
  cout << "----------------" << endl;
  
}
