// $Id: J4VTXPixelAreaHit.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4VTXPixelAreaHit
//* --------------------
//* (Description)
//* 	Derivated concreate hit class for J4VTXPixelArea.
//*	Mother class : J4VHit
//*     
//* (Update Record)
//*	2001/02/18  K.Hoshina	Original version.
//*************************************************************************

#include <iomanip.h>
#include "J4VTXPixelAreaHit.hh"

//=========================================================================
//---------------------
// Allocator
//---------------------

J4VTXPixelAreaHitAllocator J4VTXPixelAreaHit::fHitAllocator ;

//=========================================================================
//* constructor -----------------------------------------------------------

J4VTXPixelAreaHit::J4VTXPixelAreaHit(
				     G4int                 trackID ,
				     G4ParticleDefinition* particle,
				     G4int                 layerID ,
				     G4int                 ladderID ,
				     G4int                 sensorID,
				     G4int                 pixthetaID,
				     G4int                 pixphiID,
				     G4double              edep    ,
				     const G4ThreeVector  momentum,
				     G4double  energy,
				     const G4ThreeVector  pixPos,
				     const G4ThreeVector  inPos ,
				     const G4ThreeVector  outPos,
				     const G4ThreeVector  localpixPos,
				     const G4ThreeVector  localinPos ,
				     const G4ThreeVector  localoutPos ):
  fTrackID(trackID),fPID(particle),fLayerID(layerID),fLadderID(ladderID),
  fSensorID(sensorID),fPixThetaID(pixthetaID),fPixPhiID(pixphiID),
  fEdep(edep),fMomentum(momentum),fEnergy(energy),fPixPosition(pixPos),
  fInPosition(inPos),fOutPosition(outPos),fLocalInPosition(localpixPos),
  fLocalOutPosition(localinPos),fLocalPixPosition(localoutPos)
{  
}

//=========================================================================
//* destructor -----------------------------------------------------------

J4VTXPixelAreaHit::~J4VTXPixelAreaHit()
{
}

//=========================================================================
G4ThreeVector J4VTXPixelAreaHit::GetHitPosition(){
  G4double x  = (fOutPosition.x() + fInPosition.x())/2.;
  G4double y  = (fOutPosition.y() + fInPosition.y())/2.;
  G4double z  = (fOutPosition.z() + fInPosition.z())/2.;
  G4ThreeVector hit(x,y,z);
  return hit;
}
//=========================================================================
//* Output ------------------------------------------------------------------
void J4VTXPixelAreaHit::Output(G4HCofThisEvent* HCTE)
{
	
  // output hitdata to output file ....
  
  ofstream& ofs = GetOutputFileStream();
  if(! ofs.good()) {
    G4String errorMessage= "J4CDCDriftRegionHit::Output(): write error.";
    G4Exception(errorMessage);
  }  
  else
  {
     ofs << fEdep/keV << " keV" <<endl;
     ofs << fTrackID << " " << fLayerID 
	 <<" " << fLadderID <<" "<< fSensorID
     	 <<" " << fPixThetaID <<" " << fPixPhiID <<endl;
     ofs << fInPosition <<" " << fOutPosition << endl;  	
  }
}
	
//=========================================================================
//* Draw ------------------------------------------------------------------

void J4VTXPixelAreaHit::Draw()
{
}

//=========================================================================
//* Print -----------------------------------------------------------------
void J4VTXPixelAreaHit::Print()
{

  G4ThreeVector fHitPosition=GetHitPosition();

  cerr << setiosflags(ios::fixed);
  cerr << " track#=" << fTrackID
	 << " position(mm)= " << setprecision(2) 
	 << setw(8) << fHitPosition.x() *(1./mm) << " "
	 << setw(8) << fHitPosition.y() *(1./mm) << " "
	 << setw(8) << fHitPosition.z() *(1./mm) << " "
	 << " Edep(keV)= " << setprecision(2) 
	 << setw(6) << fEdep *(1./keV) << " "
         << G4endl;  
}



