// $Id: J4VTXSensor.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4VTXSensor
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4VTXSensor.hh"
#include "G4Box.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------


G4String J4VTXSensor::fName("Sensor");
G4LogicalVolume* J4VTXSensor::fStaticLV=NULL;

//=====================================================================
//---------------------
// Class Description
//---------------------
//=====================================================================
//* constructor -------------------------------------------------------

J4VTXSensor::J4VTXSensor(J4VDetectorComponent* parent,G4int numOfSensors):
  	   J4VVTXDetectorComponent(fName, parent, numOfSensors,1, 0)
{   
  // Define Sensor parameters ----------------//    
  fDxyzSensor = new G4ThreeVector(DXYZ_SENSOR);
}

//=====================================================================
//* destructor --------------------------------------------------------

J4VTXSensor::~J4VTXSensor()
{
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4VTXSensor::Assemble() 
{   
  if(!GetLV())
  {	  
    // define geometry
      
    // MakeSolid ----------//
    SetSolid(new G4Box(fName,fDxyzSensor->x()/2.,
		                fDxyzSensor->y()/2.,
		                fDxyzSensor->z()/2.));
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()-> Order(_SENSORMATERIAL_));
    LoadLV( );
    // SetVisAttribute ----//
    PaintLV( _VTXSENSORVISATT_ , G4Color(0.,0.,1.));    

    SetMaxAllowedStep(0.001*mm);
        
    // Install daughter PV //
    // Install Sensor      //
    fSubstrate  = new J4VTXSubstrate(this);
    fEpitaxial  = new J4VTXEpitaxial(this);
    fSubstrate->InstallIn(this);  
    SetDaughter(fSubstrate);
    fEpitaxial->InstallIn(this);  
    SetDaughter(fEpitaxial);
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------
void J4VTXSensor::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4VTXSensor::InstallIn(J4VDetectorComponent* mother)
{ 

  Assemble();			// You MUST call Assemble(); at first.

  G4int layer = GetMother()->GetMother()->GetMyID();
  G4int numOfSensors = NSENSOR[layer];
  for ( G4int copyNo = 0; copyNo < numOfSensors ; copyNo++){
    fxyzSensor  = new G4ThreeVector(XYZ_SENSOR[layer][copyNo]);  
    // Placement function into mother object ------//
    G4RotationMatrix* rotM = new G4RotationMatrix;
    SetPVPlacement(rotM,*fxyzSensor,copyNo);
  }
}


//* Draw  --------------------------------------------------------
void J4VTXSensor::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4VTXSensor::Print() const
{
  cout << "-J4VTXSensor(mm)-  " <<endl;
  cout << "dx " << fDxyzSensor->x()/mm 
       << " dy "<< fDxyzSensor->y()/mm 
       << " dz "<< fDxyzSensor->z()/mm 
       << endl;
  cout << "x " << fxyzSensor->x()/mm 
       << " y "<< fxyzSensor->y()/mm 
       << " z "<< fxyzSensor->z()/mm 
       << endl;
  cout << "----------------" << endl;
  
}
