// $Id: J4VTXSubstrate.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4VTXSubstrate
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4VTXSubstrate.hh"
#include "G4Box.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------


G4String J4VTXSubstrate::fName("Substrate");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4VTXSubstrate::J4VTXSubstrate(J4VDetectorComponent* parent):
  	   J4VVTXDetectorComponent(fName, parent, 1,1, 0)
{   
  // Define Substrate parameters ----------------//    
  fDxyzSubstrate = new G4ThreeVector(DXYZ_SUBSTRATE);
  fxyzSubstrate  = new G4ThreeVector(XYZ_SUBSTRATE);
}

//=====================================================================
//* destructor --------------------------------------------------------

J4VTXSubstrate::~J4VTXSubstrate()
{
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4VTXSubstrate::Assemble() 
{   
  if(!GetLV())
  {	  
    // define geometry
    // MakeSolid ----------//
    SetSolid(new G4Box(fName,fDxyzSubstrate->x()/2.,
		                fDxyzSubstrate->y()/2.,
		                fDxyzSubstrate->z()/2.));
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()-> Order(_SUBSTRATEMATERIAL_));
    // SetVisAttribute ----//
    PaintLV( _SUBSTRATEVISATT_ , G4Color(0.5,0.,0.5));    

    SetMaxAllowedStep(0.001*mm);
        
    // Install daughter PV //
    // Install Substrate      //
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4VTXSubstrate::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4VTXSubstrate::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object ------//
  G4RotationMatrix* rotM = new G4RotationMatrix;
  SetPVPlacement(rotM,*fxyzSubstrate);
}


//* Draw  --------------------------------------------------------
void J4VTXSubstrate::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4VTXSubstrate::Print() const
{
  cout << "-J4VTXSubstrate(mm)-  " <<endl;
  cout << "dx " << fDxyzSubstrate->x()/mm 
       << " dy "<< fDxyzSubstrate->y()/mm 
       << " dz "<< fDxyzSubstrate->z()/mm 
       << endl;
  cout << "x " << fxyzSubstrate->x()/mm 
       << " y "<< fxyzSubstrate->y()/mm 
       << " z "<< fxyzSubstrate->z()/mm 
       << endl;
  cout << "----------------" << endl;
  
}
