// $Id: J4VVTXDetectorComponent.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* -----------------------
//* J4VVTXDetectorComponent
//* -----------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4VVTXDetectorComponent.hh"

J4VTXMaterialStore* J4VVTXDetectorComponent::fMaterialStore = 0;

G4String J4VVTXDetectorComponent::fSubGroup("VTX");

//=====================================================================
//---------------------
// class 
//---------------------

//=====================================================================
//* default constructor -----------------------------------------------

J4VVTXDetectorComponent::J4VVTXDetectorComponent(
			   	G4String& name, 
  			   	J4VDetectorComponent *parent,
  			   	G4int nclones,
  			   	G4int nbrothers, 
  			   	G4int me		  ) : 
                         J4VDetectorComponent(fSubGroup, name, 
                         		      parent, nclones,	 
                         		      nbrothers, me  )   
{ 
#include "J4VTXParameter.icc"
}


//=====================================================================
//* destructor --------------------------------------------------------

J4VVTXDetectorComponent::~J4VVTXDetectorComponent()
{	
   if(fMaterialStore) delete fMaterialStore;
   if(fSubGroup)      delete fSubGroup;
}

//=====================================================================
//* SetMaxAllowedStep

void J4VVTXDetectorComponent::SetMaxAllowedStep(G4double maxStep){

    G4UserLimits* userLimits = new G4UserLimits;
    userLimits->SetMaxAllowedStep(maxStep);
    GetLV()->SetUserLimits(userLimits);

} 

//=====================================================================
//* SetPVPlacement ----------------------------------------------------

void J4VVTXDetectorComponent::SetPVPlacement(G4RotationMatrix *pRot,
                                          const G4ThreeVector &tlate, 
					     G4int copyNo,
					     G4LogicalVolume* mothelog)   
{
  G4LogicalVolume*  motherLV = (GetMother() ? GetMother()->GetLV():mothelog);  

  SetPV( new G4PVPlacement(pRot,		// Rotation matrix
    		     	   tlate, 		// Three vector of center position
    			   GetLV(), 		// Logical volume
    			   GetName(),	 	// Name of Physical volume
    		           motherLV,  		// Mother Logical
    			   FALSE,		// pMany
    			   copyNo  ) 		// pCopyNo	
	 );
}  

//=====================================================================
//* OpenMaterialStore -------------------------------------------------

J4VMaterialStore* J4VVTXDetectorComponent::OpenMaterialStore()
{
   if(!fMaterialStore) {
   	fMaterialStore = new J4VTXMaterialStore();
  	G4cerr << "*** Opend J4VTXMaterialStore ***" << G4endl;
  }
    
   return fMaterialStore;
}


